#!/usr/bin/env bash
# ================================================================================
#
# REGISTER :: SSH
# SSH command to register/ unregister
#
# --------------------------------------------------------------------------------
# ah - Axel Hahn <axel.hahn@iml.unibe.ch>
#
# 2021-05-31  ah  v1.0  first lines
# 2022-02-11  ah  v1.1  fix shellcheck; fix returncode of ssh command
# ================================================================================

# --------------------------------------------------------------------------------
# FUNCTIONS
# --------------------------------------------------------------------------------

# @private function
# detect ssh params and storage-registercmd to run ssh remote command
# param  string  action; one of register|unregrister|status
# param  string  hostname; given for register and unregister
function _runssh(){
  local _rc=0
  sProtocol=$(j_getFullTarget "" | cut -f 1 -d ":")
  if [ "${sProtocol}" = "rsync" -o "${sProtocol}" = "scp" -o "${sProtocol}" = "sftp" ]; then

    sSshTarget=$(j_getFullTarget "" | cut -f 3 -d "/")
    if [ -n "$sSshTarget" ]; then

      sSshParams=
      sFileSshPrivkey=$(_j_getvar ${STORAGEFILE} "ssh-privatekey")
      if [ -n "$sFileSshPrivkey" ]; then
        sSshParams="${sSshParams} -i ${sFileSshPrivkey}"
      fi

      sSshCmd=$(_j_getvar "${STORAGEFILE}" "storage-registercmd")
      
      if [ -z "$sSshCmd" ]; then
        echo "WARNING: Missing storage-registercmd = ... in ${STORAGEFILE} for a command to execute via SSH."
        _rc=1
      else
        echo "ssh ${sSshParams} ${sSshTarget} ${sSshCmd} $*"
        color cmd
        ssh ${sSshParams} ${sSshTarget} ${sSshCmd} $*
        _rc=$?
        color reset
      fi
    fi
  else
    echo "INFO: storage protocol is $sProtocol - skipping register via ssh."
  fi
  return $_rc
}

# --------------------------------------------------------------------------------
# functions called in [APPDIR]/transfer.sh

function registerBackupSlot(){
    _runssh register $1
}

function unregisterBackupSlot(){
    _runssh unregister $1
}
function statusBackupSlot(){
    _runssh status
}

# --------------------------------------------------------------------------------